==> pytorch_tools-0.1.4.tar.gz: pytorch_tools-0.1.4/pytorch_tools/fit_wrapper/README.md <==
# Overview
This module contains model runner (very close to `model.fit` in Keras) for **supervised** tasks.  
`Runner` is used to actually run the train loop calling `Callbacks` at appropriate times.  
Mixed precision (powered by apex) is supported implicitly. Users are expected to initialize their models before creating runner using `apex.amp.initialize`.

## Minimal example
This code will run training for 5 epochs.
```python
from pytorch_tools.fit_wrapper import Runner
import apex
model = ... (any model)
optimizer = ... (any optimizer)
criterions = ... (any loss function)
metrics = ... (any metrics or None)
train_loader = ... (dataloader with defined __len__)
model, optimizer = apex.amp.initialize(model, optimizer)
runner = Runner(model, optimizer, criterion, metrics)
runner.fit(train_loader, epochs=5)
```

## Real example 
This code will run training for 5 epochs with validation every epoch. 
* `Timer` will measure performance of your dataloader in comparison to model time. 
* `ConsoleLogger` will print training logs to console. 
* `TensorBoard` will log training loss and metrics to TensorBoard. 
* `CheckpointSaver` will save best model according to validation loss.
```python
import pytorch_tools as pt
val_loader = ... (validation dataloader with defined __len__)
runner = pt.fit_wrapper.Runner(
    model,
    optimizer,
    criterion,
    metrics=[pt.metrics.Accuracy(5)],
    callbacks=[
        Timer(),
        ConsoleLogger(),
        TensorBoard(log_dir="/tmp/"),
        CheckpointSaver(save_dir="/tmp/"),
    ]
)
runner.fit(train_loader, epochs=5, val_loader=val_loader)
```

==> pytorch_tools-0.1.5.tar.gz: pytorch_tools-0.1.5/pytorch_tools/fit_wrapper/README.md <==
# Overview
This module contains model runner (very close to `model.fit` in Keras) for **supervised** tasks.  
`Runner` is used to actually run the train loop calling `Callbacks` at appropriate times.  
Mixed precision (powered by apex) is supported implicitly. Users are expected to initialize their models before creating runner using `apex.amp.initialize`.

Main idea of this runner is to be as simple as possible. All core functionality is ~100 lines of code. 

## Minimal example
This code will run training for 5 epochs.
```python
from pytorch_tools.fit_wrapper import Runner
import apex
model = ... (any model)
optimizer = ... (any optimizer)
criterions = ... (any loss function)
metrics = ... (any metrics or None)
train_loader = ... (dataloader with defined __len__)
model, optimizer = apex.amp.initialize(model, optimizer)
runner = Runner(model, optimizer, criterion, metrics)
runner.fit(train_loader, epochs=5)
```

## Real example 
This code will run training for 5 epochs with validation every epoch. 
* `Timer` will measure performance of your dataloader in comparison to model time. 
* `ConsoleLogger` will print training logs to console. 
* `TensorBoard` will log training loss and metrics to TensorBoard. 
* `CheckpointSaver` will save best model according to validation loss.
```python
import pytorch_tools as pt
val_loader = ... (validation dataloader with defined __len__)
runner = pt.fit_wrapper.Runner(
    model,
    optimizer,
    criterion,
    metrics=[pt.metrics.Accuracy(5)],
    callbacks=[
        Timer(),
        ConsoleLogger(),
        TensorBoard(log_dir="/tmp/"),
        CheckpointSaver(save_dir="/tmp/"),
    ]
)
runner.fit(train_loader, epochs=5, val_loader=val_loader)
```

## How to
### Add custom step logic  
Monkey patch `Runner._make_step` function with yours  

### Process multiple inputs/outputs
Instead of modifying Runner move this logic inside Loss function.
